"""The version number is based on semantic versioning.

References
- https://semver.org/
- https://www.python.org/dev/peps/pep-0440/

This file is autogenerated, do not modify by hand.
"""
__version__ = "1.0.0-beta.6"
COMMIT = "88d4dfe9dc06665d05a13b6771c3f85512541ef3"
MAJOR = 1
MINOR = 0
PATCH = 0
